// -*- c++ -*-

/*
 * Jakelib2 - General purpose C++ library
 * Copyright (C) 2001 Florian Wolff  (florian@donuz.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: FileInfo.h,v 1.4 2006-02-18 16:04:15 florian Exp $
 */

#ifndef INCLUDE_JAKELIB2_IO_FILEINFO_H
# define INCLUDE_JAKELIB2_IO_FILEINFO_H

#if defined(HAVE_TIME_H) || defined(MSVC)
# include <time.h>
#endif

namespace jakelib {
  namespace io {
    class File;

    /**
     * Encapsulates a snapshot of a File's meta attributes such as modification time,
     * size or whether it's a regular file, a link or a directory.
     *
     * <p>If it's a symbolic link, the meta data is read from the file it points to.
     *
     * @class FileInfo
     * @version $Id: FileInfo.h,v 1.4 2006-02-18 16:04:15 florian Exp $
     * @author Florian 'Overflo' Wolff (florian@donuz.de)
     */
    class FileInfo : public jakelib::lang::Object
      {
      public:
        /**
         * Constructs a new \c FileInfo for the given \c File.
         */
	FileInfo(File* file);

        /**
         * Determines whether the \c File represents a directory.
         */
	virtual jboolean isDirectory();

        /**
         * Determines whether the \c File represents a regular file or a link to a regular file.
         */
	virtual jboolean isFile();

        /**
         * Determines whether the file's system flag is set (Windows only).
         */
	virtual jboolean isSystem();

        /**
         * Determines whether the file's hidden flag is set (Windows only).
         */
	virtual jboolean isHidden();

        /**
         * Determines whether the \c File represents a symbolic link.
         */
	virtual jboolean isLink();

        /**
         * returns the file's size in bytes.
         */
	virtual jlong length();

        /**
         * Returns the file's last modification date as unix timestamp.
         */
	virtual jlong lastModified();

        /**
         * Returns the corresponding \c File.
         */
        virtual File* getFile();

        /**
         * If this represents a symbolic link, returns the link destination path.
         */
        virtual jakelib::lang::String* readlink();

      private:

        File* file;
	long _length;
	jboolean _isFile;
	jboolean _isDirectory;
	jboolean _isSystem;
	jboolean _isHidden;
	jboolean _isLink;

	jlong _aTime;
	jlong _mTime;

	jakelib::lang::String* _linkDest;

	void init(File* file);

	JAKELIB_DECLARE_CLASS(FileInfo);
      };

    JAKELIB_DECLARE_ARRAY(FileInfo);
  }
}
#endif

